import logging
import os
from inventory_provider import config
import redis.sentinel

logger = logging.getLogger(__name__)

assert os.path.isfile(os.environ['INVENTORY_PROVIDER_CONFIG_FILENAME']), (
        'config file %r not found' %
        os.environ['INVENTORY_PROVIDER_CONFIG_FILENAME'])

with open(os.environ['INVENTORY_PROVIDER_CONFIG_FILENAME']) as f:
    logging.info(
        'loading config from: %r'
        % os.environ['INVENTORY_PROVIDER_CONFIG_FILENAME'])
    inventory_provider_config = config.load(f)

if 'sentinel' in inventory_provider_config:
    params = inventory_provider_config['sentinel']
    sentinel = redis.sentinel.Sentinel(
        [(params['hostname'], int(params['port']))],
        socket_timeout=0.5)
    master = sentinel.discover_master(params['name'])
    assert master
    _broker_hostname = master[0]
    _broker_port = master[1]
else:
    params = inventory_provider_config['redis']
    _broker_hostname = params['hostname']
    _broker_port = int(params['port'])

_broker_db_index = 1  # TODO: this should be a config param

if ':' in _broker_hostname:
    # assume this means hostname is an ipv6 address
    _broker_hostname = '[%s]' % _broker_hostname

broker_url = result_backend = 'redis://%s:%d/%d' % (
    _broker_hostname, _broker_port, _broker_db_index)

logger.debug('broker_url: %r' % broker_url)

task_eager_propagates = True
